summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/chatmessagepart.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 21:04:23 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 21:04:23 -0600
commit4140fee92e2293c37a8e9aa8f21254dc66433a0a (patch)
treee34af01d770eb757086498062850842e7b525bd3 /kopete/kopete/chatwindow/chatmessagepart.h
parent44c26994c9087200cf941f08df9f77b553a1365e (diff)
downloadtdenetwork-4140fee92e2293c37a8e9aa8f21254dc66433a0a.tar.gz
tdenetwork-4140fee92e2293c37a8e9aa8f21254dc66433a0a.zip
Rename kiobuffer and KHTML
Diffstat (limited to 'kopete/kopete/chatwindow/chatmessagepart.h')
-rw-r--r--kopete/kopete/chatwindow/chatmessagepart.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/kopete/chatwindow/chatmessagepart.h b/kopete/kopete/chatwindow/chatmessagepart.h
index 10eacd11..278291bb 100644
--- a/kopete/kopete/chatwindow/chatmessagepart.h
+++ b/kopete/kopete/chatwindow/chatmessagepart.h
@@ -36,7 +36,7 @@ class ChatWindowStyle;
/**
* @author Richard Smith
*/
-class ChatMessagePart : public KHTMLPart
+class ChatMessagePart : public TDEHTMLPart
{
Q_OBJECT
@@ -233,7 +233,7 @@ private:
TQString formatMessageBody( const Kopete::Message &message );
/**
* Write the template file to KHTMLPart
*/
void writeTemplate();
@@ -233,7 +233,7 @@ private:
TQString formatMessageBody( const Kopete::Message &message );
/**
- * Write the template file to KHTMLPart
+ * Write the template file to TDEHTMLPart
*/
void writeTemplate();